.. _examples_overview:

=======================================
Examples
======================================

Examples
------------
Documented examples can be found `here <https://github.com/UT-CHG/BET/tree/master/examples>`_.
Jupyter notebooks of examples can be found `here <https://github.com/CU-Denver-UQ/BET-notebooks>`_.